package com.srs.dormitory.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.dormitory.domain.DmsOutsideAccommodationAttachment;
import org.apache.ibatis.annotations.Param;

/**
 * 外宿申请附件Service接口
 *
 * @author srs
 * @date 2025-12-05
 */
public interface IDmsOutsideAccommodationAttachmentService extends IService<DmsOutsideAccommodationAttachment> {
    /**
     * 查询外宿申请附件
     *
     * @param id 外宿申请附件主键
     * @return 外宿申请附件
     */
    public DmsOutsideAccommodationAttachment selectDmsOutsideAccommodationAttachmentById(Long id);

    /**
     * 查询外宿申请附件列表
     *
     * @param dmsOutsideAccommodationAttachment 外宿申请附件
     * @return 外宿申请附件集合
     */
    List<DmsOutsideAccommodationAttachment> selectDmsOutsideAccommodationAttachmentList(DmsOutsideAccommodationAttachment dmsOutsideAccommodationAttachment);

    /**
     * 批量插入校外住宿附件
     * @param list 校外住宿附件列表
     * @return 插入行数
     */
    int batchInsertDmsOutsideAccommodationAttachment(List<DmsOutsideAccommodationAttachment> list);

    /**
     * 新增外宿申请附件
     *
     * @param dmsOutsideAccommodationAttachment 外宿申请附件
     * @return 结果
     */
    int insertDmsOutsideAccommodationAttachment(DmsOutsideAccommodationAttachment dmsOutsideAccommodationAttachment);

    /**
     * 修改外宿申请附件
     *
     * @param dmsOutsideAccommodationAttachment 外宿申请附件
     * @return 结果
     */
    int updateDmsOutsideAccommodationAttachment(DmsOutsideAccommodationAttachment dmsOutsideAccommodationAttachment);

    /**
     * 批量删除外宿申请附件
     *
     * @param ids 需要删除的外宿申请附件主键集合
     * @return 结果
     */
    int deleteDmsOutsideAccommodationAttachmentByIds(Long[] ids);

    int deleteOutsideAccommodationAttachmentNameAndStuName(@Param("attachmentName") String attachmentName, @Param("studentName") String studentName);

    /**
     * 删除外宿申请附件信息
     *
     * @param id 外宿申请附件主键
     * @return 结果
     */
    int deleteDmsOutsideAccommodationAttachmentById(Long id);
}
